@@ -8,7 +8,7 @@ import (
 	"sync"
 	"time"
 
-	"github.com/blang/semver"
+	"github.com/blang/semver/v4"
 	"github.com/sirupsen/logrus"
 
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/client/listers/operators/v1alpha1"
@@ -506,12 +506,6 @@ func WithLabel(label string) OperatorPredicate {
 	}
 }
 
-func WithCatalog(key registry.CatalogKey) OperatorPredicate {
-	return func(o *Operator) bool {
-		return key.Equal(o.SourceInfo().Catalog)
-	}
-}
-
 func ProvidingAPI(api opregistry.APIKey) OperatorPredicate {
 	return func(o *Operator) bool {
 		for _, p := range o.Properties() {
@@ -602,9 +596,3 @@ func Filter(operators []*Operator, p ...OperatorPredicate) []*Operator {
 func Matches(o *Operator, p ...OperatorPredicate) bool {
 	return And(p...)(o)
 }
-
-func False() OperatorPredicate {
-	return func(*Operator) bool {
-		return false
-	}
-}
